@@ -29,17 +29,17 @@ class Parsy:
         self.strip_strings = strip_strings
 
     @classmethod
-    def from_file(cls, yaml_file: Path, validate: bool = True):
+    def from_file(cls, yaml_file: Path, validate: bool = True, strip_strings=False):
         if yaml_file.is_file():
             stream = yaml_file.open()
             data = yaml.load(stream, Loader=SafeLoader)
-            return cls(data, validate)
+            return cls(data, validate, strip_strings)
         raise YamlFileNotFound(yaml_file.name)
 
     @classmethod
-    def from_string(cls, yaml_string: str, validate: bool = True):
+    def from_string(cls, yaml_string: str, validate: bool = True, strip_strings=False):
         data = yaml.safe_load(yaml_string)
-        return cls(data, validate)
+        return cls(data, validate, strip_strings)
 
     def __create_field_selectors(self):
         if self._definitions:
@@ -177,10 +177,10 @@ class Parsy:
         except AttributeError:
             data = html_data
         if return_type == ReturnType.STRING:
-            return data.strip() if self.strip_strings else data
+            return data.strip() if self.strip_strings and data else data
         if return_type == ReturnType.INTEGER:
-            return extract_integer(data.strip() if self.strip_strings else data)
+            return extract_integer(data.strip() if self.strip_strings and data else data)
         if return_type == ReturnType.FLOAT:
-            return extract_float(data.strip() if self.strip_strings else data)
+            return extract_float(data.strip() if self.strip_strings and data else data)
         if return_type == ReturnType.BOOLEAN:
             return data is not None
